<?php
/**
* @author Fastball Productions
* @package com_fullcourt
* @subpackage components
* @link http://www.fastballproductions.com
* @copyright Copyright (C) 2011 Fastball Productions
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
*/

/* Change History

  10/04/12 MCrosbie - Change sort order for schedule from DESC to ASC.

*/

/* no direct access; */
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

class FullcourtModelSchedules extends JModel {
	var $_schedules;
	var $_total = null;
	var $_lists = null;
	var $_pagination = null;

	function __construct() {
		$app = &JFactory::getApplication();
		$option = JRequest::getCmd('option');
		parent::__construct();
		$this->_lists = array();
		$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->getCfg('list_limit'));
		$limitstart = $app->getUserStateFromRequest($option.'limitstart', 'limitstart', 0);
		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}

	function getSchedules() {
		$app = &JFactory::getApplication();
		$option = JRequest::getCmd('option');
		$db  =& $this->getDBO();
		$limitstart = $this->getState('limitstart');
		$limit = $this->getState('limit');

		/* get the filtered team parameter if applied; */
		$filterteam = $app->getUserStateFromRequest( "$option.filter_team_schedules", 'filter_team', '' );
		/* get the filtered league/division parameter if applied; */
		$filterdivision = $app->getUserStateFromRequest( "$option.filter_division_schedules", 'filter_division', '' );
		/* get the filtered season parameter if applied; */
		$filterseason = $app->getUserStateFromRequest( "$option.filter_season_schedules", 'filter_season', '' );
		/* get the filtered game type parameter if applied; */
		$filtergametype = $app->getUserStateFromRequest( "$option.filter_gametype_schedules", 'filter_gametype', '' );

		$this->_lists['filterteam'] = getTeamFilterList('filter_team', $filterteam);
		$this->_lists['filterdivision'] = getLeagueDivisionFilterList('filter_division', $filterdivision);
		$this->_lists['filterseason'] = getSeasonsAsFiilterList('filter_season', $filterseason);
		$this->_lists['filtergametype'] = getGameTypesAsFiilterList('filter_gametype', $filtergametype);

		$whereclause = array();
		if ($filterteam != '') {
			$whereclause[] = "(visitingteam = {$filterteam} OR hometeam = {$filterteam})";
		}
		if ($filterdivision != '') {
			$arr = explode(':', $filterdivision);
			if ($arr[0]) {
				$whereclause[] = "(h.leagueid = {$arr[0]} OR v.leagueid = {$arr[0]})";
			}
			if ($arr[1]) {
				$whereclause[] = "(h.divisionid = {$arr[1]} OR v.divisionid = {$arr[1]})";
			}
		}
		if ($filterseason != '') {
			$whereclause[] = "a.season = {$filterseason}";
		}
		if ($filtergametype != '') {
			$whereclause[] = "a.gametype = {$filtergametype}";
		}

		if (sizeof($whereclause) > 0) {
			$whereclause = implode(' AND ', $whereclause);
			$whereclause = 'WHERE (' . $whereclause;
			$whereclause .= ')';
		}
		else {
			$whereclause = '';
		}

		$query = "SELECT a.*, h.name AS hometeam, v.name AS visitingteam, t.description AS gametype, l.name AS fieldname, l.city AS city, l.state AS state, s.description AS status, n.name AS season FROM #__fullcourt_schedule AS a LEFT JOIN #__fullcourt_season AS n ON a.season = n.id LEFT JOIN #__fullcourt_team AS h ON a.hometeam = h.id LEFT JOIN #__fullcourt_team AS v ON a.visitingteam = v.id LEFT JOIN #__fullcourt_gametype AS t ON a.gametype = t.id LEFT JOIN #__fullcourt_location AS l ON a.location = l.id LEFT JOIN #__fullcourt_gamestatus AS s ON a.status = s.id " . $whereclause . "ORDER BY a.gamedatetime ASC";
		$this->_schedules = $this->_getList($query, $limitstart, $limit);
		$this->_total = $this->_getListCount($query);
		return $this->_schedules;
	}


	function delete($cids) {
		$db = $this->getDBO();
		$table = $db->nameQuote('#__fullcourt_schedule');
		$id = $db->nameQuote('id');
		$query = "DELETE FROM " . $table . " WHERE " . $id . "IN (" . implode( ',', $cids ) . ")";
		$db->setQuery( $query );

		if(!$db->query()) {
			$errorMessage = $this->getDBO()->getErrorMsg();
			JError::raiseError( 500, 'Error deleting schedules: ' . $errorMessage );
		}
	}

	function publish() {
		$db  =& $this->getDBO();
		$cid = JRequest::getVar( 'cid', array(0), '', 'array' );
		$task = JRequest::getVar( 'task', '', 'default', 'default' );
		if ($task == 'schedulepublish') {
			$publish = 1;
		}
		else {
			$publish = 0;
		}
		$table =& JTable::getInstance('schedule', 'Table');
		$table->publish($cid, $publish);
	}

	function getPagination() {
		if (empty($this->_pagination)) {
			jimport('joomla.html.pagination');
			$total = $this->_total;
			$limitstart = $this->getState('limitstart');
			$limit = $this->getState('limit');
			$this->_pagination = new JPagination($total, $limitstart, $limit);
		}
		return $this->_pagination;
	}


}

?>